import React, { useState } from 'react';
import { SVG } from 'primeobjects-ui-web-basic';
import { COLORS } from 'primeobjects-helper-util';
import { BubbleMenu } from '@tiptap/react';
import { isFunction, map, isArray, isNil } from 'lodash';
var HtmlEditorFloatHighlightToolbar = function (props) {
    var editor = props.editor;
    var _a = useState(false), showInlineEditNoteUI = _a[0], setShowInlineEditNoteUI = _a[1];
    var InlineEditNoteUI = null;
    var colors = isArray(props.colors) && props.colors.length > 0 ? props.colors : [
        COLORS.RED['100'],
        COLORS.ORANGE['100'],
        COLORS.BLUE['100'],
        COLORS.GREEN['100'],
        COLORS.GRAY['100'],
    ];
    var onClickEditNote = function () {
        if (!isFunction(props.onClickEditNote))
            return;
        InlineEditNoteUI = props.onClickEditNote(editor);
        setShowInlineEditNoteUI(true);
        //if result is not null, it is an inline editor, it will use the same block of tool bar
    };
    var onApplyColor = function (color) {
        if (editor.isActive('hightlight', { color: color })) {
            editor.chain().focus().unsetHighlight();
        }
        else {
            editor.chain().focus().toggleHighlight({ color: color }).run();
        }
        if (isFunction(props.onHighlight))
            props.onHighlight(editor, color);
    };
    var renderColorPicker = function () {
        if (showInlineEditNoteUI)
            return null;
        return map(colors, function (color) {
            var isActive = editor.isActive('hightlight', { color: color });
            return React.createElement("div", { className: "menu", key: color },
                React.createElement("div", { onClick: function () { return onApplyColor(color); }, style: { backgroundColor: color }, className: "menu-color ".concat(isActive ? 'active' : '') }, isActive && React.createElement(SVG, { src: "/icons/platform/checkmark.svg", size: 12 })));
        });
    };
    var renderEditNoteButton = function () {
        if (!isFunction(props.onClickEditNote) || showInlineEditNoteUI)
            return null;
        return React.createElement("div", { className: "menu border border-0 border-l flex", style: { marginLeft: 3, paddingLeft: 3 } },
            React.createElement("div", { onClick: onClickEditNote, className: "menu-color", style: { width: 16, height: 16 } },
                React.createElement(SVG, { src: "/icons/platform/note.svg", style: { width: 18 } })));
    };
    var renderEditNoteUI = function () {
        return InlineEditNoteUI;
    };
    return isNil(editor) ? React.createElement(React.Fragment, null) : React.createElement(BubbleMenu, { editor: editor, className: "menu-wrapper" },
        renderColorPicker(),
        renderEditNoteButton(),
        renderEditNoteUI());
};
export default HtmlEditorFloatHighlightToolbar;
